@@ -3,8 +3,10 @@
 const test = require('tape')
 const concat = require('concat-stream')
 const fs = require('fs')
+const os = require('os')
 const path = require('path')
 const helpMe = require('./')
+const proxyquire = require('proxyquire')
 
 test('throws if no directory is passed', function (t) {
   try {
@@ -317,3 +319,30 @@ test('toStdout without factory', async function (t) {
 
   t.ok(completed)
 })
+
+test('should allow for awaiting the response with default stdout stream', async function (t) {
+  t.plan(2)
+
+  const _process = Object.create(process)
+  const stdout = Object.create(process.stdout)
+  Object.defineProperty(_process, 'stdout', {
+    value: stdout
+  })
+
+  let completed = false
+  stdout.write = (data, cb) => {
+    t.equal(data.toString(), 'hello world' + os.EOL)
+    completed = true
+    cb()
+  }
+
+  const helpMe = proxyquire('./help-me', {
+    process: _process
+  })
+
+  await helpMe.help({
+    dir: 'fixture/basic'
+  })
+
+  t.ok(completed)
+})
